@@ -9,11 +9,14 @@ def union(*args):
 
 # note: using varchar has no performance advantage in postgres, so we 
 # can always just store strings in text fields
-TYPES = {
-    'boolean': BOOLEAN, 
+SCALAR_TYPES = {
     'integer': INTEGER, 
     'number': FLOAT, 
     'string': TEXT, 
+}
+
+TYPES = {
+    'boolean': BOOLEAN, 
     'array': TEXT, 
     'object': TEXT, 
 }
@@ -33,5 +36,5 @@ FORMAT_EXTENSIONS = {
     'timestamp': TIMESTAMP,     
 }
 
-generic = union(TYPES, FORMATS)
-postgresql = union(TYPES, TYPE_EXTENSIONS, FORMATS, FORMAT_EXTENSIONS)
\ No newline at end of file
+generic = union(SCALAR_TYPES, TYPES, FORMATS)
+postgresql = union(SCALAR_TYPES, TYPES, TYPE_EXTENSIONS, FORMATS, FORMAT_EXTENSIONS)
\ No newline at end of file
